class BankAccount:
    def __init__(self, bank_code, agency, account, digit):
        self.bank_code = bank_code
        self.agency = agency
        self.account = account
        self.digit = digit
